@@ -9,7 +9,7 @@ use JSON;
 
 # ABSTRACT: A Perl implementation of reCAPTCHA API version 2
 
-our $VERSION = '0.2'; # VERSION
+our $VERSION = '0.3'; # VERSION
 
 
 sub new {
@@ -36,9 +36,9 @@ sub _element_id {
 }
 
 sub _recaptcha_script {
-    my ($sitekey, $options) = @_;
+    my ($self, $sitekey, $options) = @_;
 
-    my $json_options = encode_json({ sitekey => $sitekey, %$options });
+    my $json_options = to_json({ sitekey => $sitekey, %$options }, $self->{json_options} || {});
 
     return '<script type="text/javascript">var onloadCallback = function(){grecaptcha.render(\''
         . _element_id($sitekey) . '\',' . $json_options . ');};</script>';
@@ -58,7 +58,7 @@ sub html {
         croak 'Options must be a reference to hash';
     }
 
-    my $script = _recaptcha_script($sitekey, $options);
+    my $script = $self->_recaptcha_script($sitekey, $options);
 
     return join(
         '',
@@ -117,7 +117,7 @@ Captcha::reCAPTCHA::V2 - A Perl implementation of reCAPTCHA API version 2
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
